=====
Usage
=====

Once the validations-common project has been installed,
navigate to the chosen share path, usually `/usr/share/ansible`
to access the installed roles, playbooks, and libraries.

While the validations-common can be run by itself,
it nonetheless depends on Ansible and validations-libs.
Therefore it isn't recommended to use only validations-common.

The validations included with validations-common are intended to be demonstrations,
capable of running on most setups. But they are not meant for production environment.
